********
speclite
********

This package provides a set of lightweight utilities for working with spectroscopic data in astronomy.

.. toctree::
  :maxdepth: 1

  overview.rst
  install.rst
  filters.rst
  api.rst
